@@ -22,7 +22,7 @@ class ChapterAndPageBlock(BaseObject):
 
     def __init__(self,
                  emojis: Optional[List[str]] = None,
-                 target_user_ids: Optional[List[str]] = None):
+                 target_users: Optional[str] = None):
         """ Change Log
 
         Created:
@@ -43,12 +43,12 @@ class ChapterAndPageBlock(BaseObject):
         Args:
             emojis (Optional[List[str]], optional): list of emojis to use in display block. Defaults to None.
                 if left empty, will sample from 'book' themed slack emojis
-            target_user_ids (Optional[List[str]], optional): the Slack User ID to target with this response. Defaults to None.
+            target_users (Optional[str], optional): the Slack User IDs to target with this response. Defaults to None.
                 if left empty, the response will not target any specific Slack IDs
         """
         BaseObject.__init__(self, __name__)
         self._emojis = emojis
-        self._target_user_ids = target_user_ids
+        self._target_users = target_users
 
     def _book_name_text(self,
                         chapter_number: int,
@@ -207,6 +207,8 @@ class ChapterAndPageBlock(BaseObject):
             dict: the display block
         """
 
+        primary_text = f"{self._target_users} {primary_text}".strip()
+
         book_name_text = self._book_name_text(
             book_name=book_name,
             chapter_number=chapter_number)
